==> libgwenhywfar_4.0.3.orig.tar.gz: gwenhywfar-4.0.3/src/parser/dbio_l.h <==
/***************************************************************************
 begin       : Wed Mar 31 2004
 copyright   : (C) 2004-2010 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


/** @file src/parser/dbio.h */

#ifndef GWENHYWFAR_DBIO_L_H
#define GWENHYWFAR_DBIO_L_H


#include <gwenhywfar/dbio_be.h>


int GWEN_DBIO_ModuleInit();
int GWEN_DBIO_ModuleFini();


#endif /* GWENHYWFAR_DBIO_P_H */

==> libgwenhywfar_5.12.2.orig.tar.gz: gwenhywfar-5.12.2/src/parser/dbio_l.h <==
/***************************************************************************
 begin       : Wed Mar 31 2004
 copyright   : (C) 2004-2010 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


/** @file src/parser/dbio.h */

#ifndef GWENHYWFAR_DBIO_L_H
#define GWENHYWFAR_DBIO_L_H


#include <gwenhywfar/dbio_be.h>


int GWEN_DBIO_ModuleInit(void);
int GWEN_DBIO_ModuleFini(void);


#endif /* GWENHYWFAR_DBIO_P_H */
